@@ -120,7 +120,7 @@ def setAsyncHttpMaxNum(value: int):
 
 
 async def asyncHttpGet(url: str, headers: Optional[dict[str, str]] = None, timeout: int = 30, retry: int = 3):
-    initAioHttp()
+    # initAioHttp()
     global _currentAsyncHttpNum
     headers = getHeaderByDefault(headers)
     result: bytes = b""
@@ -154,7 +154,7 @@ async def asyncHttpGet(url: str, headers: Optional[dict[str, str]] = None, timeo
 
 
 async def asyncHttpPost(url: str, data: Optional[Any] = None, headers: Optional[dict[str, str]] = None, timeout: int = 30, retry: int = 3):
-    initAioHttp()
+    # initAioHttp()
     global _currentAsyncHttpNum
     headers = getHeaderByDefault(headers)
     result = None
@@ -193,30 +193,36 @@ async def asyncDownload(url: str, file: str):
     await asyncWriteBinFile(file, result)
 
 
-_isInitAioHttp = True
+# 两个方案都能解决问题
+# asyncio.run(runAsync())
+# =>
+# asyncio.get_event_loop().run_until_complete(runAsync())
 
+# --------------------------------------------------------------------
 
-def initAioHttp():
+# _isInitAioHttp = True
 
-    global _isInitAioHttp
-    if _isInitAioHttp:
-        _isInitAioHttp = False
-    else:
-        return
+# def initAioHttp():
 
-    # from asyncio.proactor_events import _ProactorBasePipeTransport
-    # from functools import wraps
+#     global _isInitAioHttp
+#     if _isInitAioHttp:
+#         _isInitAioHttp = False
+#     else:
+#         return
 
-    # # 尝试优化报错：RuntimeError: Event loop is closed
+#     from asyncio.proactor_events import _ProactorBasePipeTransport
+#     from functools import wraps
 
-    # def silence_event_loop_closed(func):
-    #     @wraps(func)
-    #     def wrapper(self, *args, **kwargs):
-    #         try:
-    #             return func(self, *args, **kwargs)
-    #         except RuntimeError as e:
-    #             if str(e) != 'Event loop is closed':
-    #                 raise
-    #     return wrapper
+#     # 尝试优化报错：RuntimeError: Event loop is closed
 
-    # _ProactorBasePipeTransport.__del__ = silence_event_loop_closed(_ProactorBasePipeTransport.__del__)
+#     def silence_event_loop_closed(func):
+#         @wraps(func)
+#         def wrapper(self, *args, **kwargs):
+#             try:
+#                 return func(self, *args, **kwargs)
+#             except RuntimeError as e:
+#                 if str(e) != 'Event loop is closed':
+#                     raise
+#         return wrapper
+
+#     _ProactorBasePipeTransport.__del__ = silence_event_loop_closed(_ProactorBasePipeTransport.__del__)
