@@ -54,7 +54,7 @@ def _checkLockFile():
     if os.path.isfile(lockFile):
         if _isDev():
             print(f"不支持重复执行 {lockFile}")
-            hold("当前调试模式下，输入unlock可继续：", True, "unlock")
+            hold("当前调试模式下，输入unlock可继续", True, "unlock")
         else:
             raise Exception(f"不支持重复执行 {lockFile}")
     writeFile(lockFile, time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))
