@@ -1,9 +1,8 @@
 from beniutils import getPath
 from beniutils.task import initTask
 
-import main_config
+from conf.main_conf import devTaskList
 
 exeWorkspace = getPath("./workspace")
 devWorkspace = getPath("./../../workspace")
-devTaskList = main_config.taskList
 initTask(exeWorkspace, devWorkspace, devTaskList)
